@@ -246,6 +246,8 @@ class DtUtil:
         @param src_dt:源日期
         @param dst_df:目标日期字符串格式
         """
+        if dst_df == DtUtil.DF_INFLUX:
+            src_dt += relativedelta(hours=-8)
         return dt.datetime.strftime(src_dt, dst_df)
 
     @staticmethod
